TIME_TO_WAIT = 3  # in seconds
TIME_TO_NEXT_PAGE = 10  # in seconds
STUDENTS_ENROLLED_XPATH1 = '//main//div[@class = "_1fpiay2" ]//strong'
STUDENTS_ENROLLED_XPATH2 = '//main//div[@class = "css-oj3vzs" ]//span'
TIME_REQ_XPATH1 = '//main//div[@class = "_16ni8zai m-b-0"]//span'
TIME_REQ_XPATH2 = '//main//div[@class = "_16ni8zai m-b-0 m-t-1s"]//span'
PAGINATION_CONTAINER = '//main//div[@class="pagination-controls-container"]'
PAGINATION_BUTTON_XPATH = PAGINATION_CONTAINER + '//button[@data-e2e="pagination-number-box"]'
COURSE_CARD_XPATH = '//main//ul//li'
COURSE_CARD_LINK_XPATH = '//a[@data-click-key="search.search.click.search_card"]'
LEARNERS_XPATH = '//main//div [@class = "learners-count"]//span'
DIFFICULTY_XPATH = '//div[@class="css-ilhc4l"]/div[2]/p'
SUBCOURSE_XPATH = '//main//div[@class = "_jyhj5r CourseItem"]//h3'
TITLE_XPATH = '//main//h1'
INSTITUTE_XPATH = '//div[@class="css-17cbn3s"]//span'
RATING_XPATH = '//main//span[@class="_16ni8zai m-b-0 rating-text number-rating m-l-1s m-r-1"]'
RECENT_VIEWS_XPATH = '//main//div[@class = "_bd90rg" ]//span'
SKILL_XPATH = '//main//ul[@class = "css-uqope5"]//li'
